SystemOrganization addCategory: #'Grease-Tests-Pharo20-Core'!

!GRPrinterTest methodsFor: '*grease-tests-pharo20-core' stamp: 'pmm 9/15/2013 12:27'!
testScaledDecimalPrinter
	| converter |
	converter := GRNumberPrinter new precision: 2.
	self assert: (converter print: 1.009s3) = '1.01'.
	self assert: (converter print: 1.01s2) = '1.01'.
	self assert: (converter print: 1.019s3) = '1.02'.
	self assert: (converter print: 1.25s2) = '1.25'.
	self assert: (converter print: 1.254s3) = '1.25'.
	self assert: (converter print: 1.256s3) = '1.26'.
	self assert: (converter print: 1.009s3) = '1.01'.
	self assert: (converter print: 0.9s1) = '0.90'.
	self assert: (converter print: 0.99s2) = '0.99'.
	self assert: (converter print: 0.999s3) = '1.00'.
	self assert: (converter print: 0.9999s4) = '1.00'.
	self assert: (converter print: -0.9s1) = '0.90'.
	self assert: (converter print: -0.99s2) = '0.99'.
	self assert: (converter print: -0.999s3) = '1.00'.
	self assert: (converter print: -0.9999s4) = '1.00'! !

!GRUtf8CodecTest methodsFor: '*grease-tests-pharo20-core' stamp: 'JohanBrichau 8/22/2013 19:54'!
expectedFailures
	^ #(testCodecUtf8ShortestForm)! !

TestCase subclass: #GRPharoCodecTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Grease-Tests-Pharo20-Core'!

!GRPharoCodecTest methodsFor: 'private' stamp: 'pmm 4/21/2012 20:54'!
assert: aString next: anInteger startingAt: startIndex gives: anEncodedString
	| actual |
	actual := String streamContents: [ :stream |
		((GRCodec forEncoding: 'utf-8') encoderFor: stream)
			greaseNext: anInteger putAll: aString startingAt: startIndex ].
	self assert: actual = anEncodedString! !

!GRPharoCodecTest methodsFor: 'private' stamp: 'pmm 12/26/2010 22:24'!
assertEncodingIgnoresLanguageTat: aStringWithLanguageTag
	| codec withLanguageTag withoutLanguageTag |
	codec := GRCodec forEncoding: 'utf-8'.
	withLanguageTag := codec encode: aStringWithLanguageTag.
	withoutLanguageTag := codec encode: (self stripLeadingCharFrom: aStringWithLanguageTag).
	self assert: withLanguageTag = withoutLanguageTag! !

!GRPharoCodecTest methodsFor: 'private' stamp: 'pmm 12/26/2010 22:13'!
stripLeadingCharFrom: aString 
	"strips the leadingChar from every character in the given string"
	^ String streamContents: [ :stream | 
		aString do: [ :each | 
			stream nextPut: (Character 
				leadingChar: 0
				code: each greaseInteger) ] ]! !

!GRPharoCodecTest methodsFor: 'tests' stamp: 'pmm 8/16/2010 00:24'!
testAllCodesIncludesIso88591
	self assert: (GRCodec allCodecs anySatisfy: [ :each |
		each name = 'iso-8859-1' ])! !

!GRPharoCodecTest methodsFor: 'tests' stamp: 'pmm 5/21/2014 20:43'!
testGreaseNextPutAllStartingAt
	| umlaut encodedUmlaut |
	umlaut := String with: (Character codePoint: 228).
	encodedUmlaut := String with: (Character codePoint: 195) with: (Character codePoint: 164).
	self assert: 'ab' next: 1 startingAt: 1 gives:  'a'.
	self assert: 'a', umlaut, 'b' next: 1 startingAt: 1 gives:  'a'.
	self assert: 'ab', umlaut next: 1 startingAt: 1 gives:  'a'.
	self assert: 'a', umlaut, 'b' next: 2 startingAt: 1gives:  'a', encodedUmlaut.
	self assert: 'a', umlaut, 'b' next: 1 startingAt: 2 gives:  encodedUmlaut.
	self assert: 'a', umlaut, 'b' next: 2 startingAt: 2 gives:  encodedUmlaut, 'b'.
	self assert: 'a', umlaut, umlaut next: 2 startingAt: 2 gives:  encodedUmlaut, encodedUmlaut.
	self assert: 'ab', umlaut, 'b', umlaut next: 3 startingAt: 2 gives:  'b', encodedUmlaut, 'b'! !

!GRPharoCodecTest methodsFor: 'tests' stamp: 'pmm 12/26/2010 22:25'!
testLanguageTag
	"this makes sure the encoder doesn't fall on the nose with unicode"
	"Make Japanese String from unicode. see http://www.unicode.org/charts/PDF/U3040.pdf"
	| leading hiraA hiraO hiraAO |
	leading := (Smalltalk classNamed: #JapaneseEnvironment) leadingChar.
	hiraA := (Character 
		leadingChar: leading
		code: 12354) greaseString.	"HIRAGANA LETTER A"
	hiraO := (Character 
		leadingChar: leading
		code: 12362) greaseString.	"HIRAGANA LETTER O"
	hiraAO := hiraA , hiraO.
	self assertEncodingIgnoresLanguageTat: hiraA.
	self assertEncodingIgnoresLanguageTat: hiraO.
	self assertEncodingIgnoresLanguageTat: hiraAO! !

TestCase subclass: #GRPharoColorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Grease-Tests-Pharo20-Core'!

!GRPharoColorTest methodsFor: 'testing' stamp: 'lr 7/25/2011 19:51'!
expectedFailures
	^ #(testFromStringThreeDigit)! !

!GRPharoColorTest methodsFor: 'testing' stamp: 'lr 7/25/2011 18:34'!
testAllColors
	| toTest |
	toTest := #(
		16r000000 16r000001 16r000101 16r010101 16r010100 16r010000 16r001001 16r101001
		16r001122 16r334455 16r667788 16r99AABB 16rCCDDEE 16rFF0011
		16r123456 16r789ABC 16rDEFEDC
		16rFEFEEF 16rFEFEFF 16rFEFEFE 16rFFFEFE 16rFFFFFE 16rFFFFFF).
	toTest do: [ :int | 
		| hex |
		hex := int printPaddedWith: $0 to: 6 base: 16.
		self assert: (Color fromString: hex) asHTMLColor asLowercase = ('#', hex) asLowercase ]! !

!GRPharoColorTest methodsFor: 'testing' stamp: 'MAD 8/29/2008 15:36'!
testColorAsHtmlColor
	"test for:
	Color >> #hex
	| aStream |
	aStream := (String new: 6) writeStream.
	aStream nextPutAll: (((self red * 255) asInteger printStringBase: 16)
		padded: #left to: 2 with: $0).
	aStream nextPutAll: (((self green * 255) asInteger printStringBase: 16)
		padded: #left to: 2 with: $0).
	aStream nextPutAll: (((self blue * 255) asInteger printStringBase: 16)
		padded: #left to: 2 with: $0).
	^ aStream contents

	Color >> #asHTMLColor
	^ '#', self hex"
	self assert: (#('#ffffff' '#FFFFFF' ) includes: Color white asHTMLColor).
	self assert: (Color black asHTMLColor = '#000000').
	self assert: (#('#ff0000' '#FF0000' ) includes: Color red asHTMLColor)! !

!GRPharoColorTest methodsFor: 'testing' stamp: 'pmm 11/20/2008 22:00'!
testFromSixDigit
	self assert: (Color fromString: 'ff0000') = Color red.
	self assert: (Color fromString: 'FF0000') = Color red.
	self assert: (Color fromString: '#ff0000') = Color red.
	self assert: (Color fromString: '#FF0000') = Color red
! !

!GRPharoColorTest methodsFor: 'testing' stamp: 'pmm 8/25/2016 10:59'!
testFromStringName
	self assert: (Color fromString: 'red') = Color red.
	self assert: (Color fromString: 'RED') = Color red.
	self assert: (Color fromString: '#red') = Color red.
	self assert: (Color fromString: '#RED') = Color red
! !

!GRPharoColorTest methodsFor: 'testing' stamp: 'pmm 11/20/2008 22:01'!
testFromStringSixDigit
	self assert: (Color fromString: 'ff0000') = Color red.
	self assert: (Color fromString: 'FF0000') = Color red.
	self assert: (Color fromString: '#ff0000') = Color red.
	self assert: (Color fromString: '#FF0000') = Color red
! !

!GRPharoColorTest methodsFor: 'testing' stamp: 'pmm 8/25/2016 11:00'!
testFromStringThreeDigit
	self assert: (Color fromString: 'f00') = Color red.
	self assert: (Color fromString: 'F00') = Color red.
	self assert: (Color fromString: '#f00') = Color red.
	self assert: (Color fromString: '#F00') = Color red! !

TestCase subclass: #GRPharoGenericCodecTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Grease-Tests-Pharo20-Core'!

!GRPharoGenericCodecTest methodsFor: 'tests' stamp: 'pmm 8/16/2010 00:47'!
testNoAmbiguities
	#('utf-8' 'UTF-8' 'utf8') do: [ :each |
		self deny: (GRPharoGenericCodec supportsEncoding: each) ].
	GRPharoLatin1Codec supportedEncodingNames do: [ :each |
		self deny: (GRPharoGenericCodec supportsEncoding: each) ]! !

TestCase subclass: #GRPharoPlatformTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Grease-Tests-Pharo20-Core'!

!GRPharoPlatformTest methodsFor: 'running' stamp: 'pmm 9/12/2013 18:03'!
runCase
	GRPharoPlatform current doSilently:  [ super performTest ]! !

!GRPharoPlatformTest methodsFor: 'tests' stamp: 'JohanBrichau 4/19/2014 17:14'!
testCompileIntoClassified
	| source protocol selectors selector |
	source := 'aMethod
	^ ''a result'''.
	protocol := 'a-protocol'.
	selector := #aMethod.
	GRPlatform current 
		compile: source
		into: self class
		classified: protocol.
	
	[ self assert: (self class selectors includes: selector).
	selectors := self class organization listAtCategoryNamed: protocol.
	self assert: selectors = (Array with: selector) ] ensure: [ self class removeSelector: selector ]! !

!GRPharoPlatformTest methodsFor: 'tests' stamp: 'jf 10/6/2008 14:37'!
testFullName
	self assert: Object fullName = 'Object'! !

!GRPharoPlatformTest methodsFor: 'tests' stamp: 'pmm 12/26/2010 21:44'!
testGreaseIntegerOnCharacter
	| character |
	character := Character codePoint: 19982.
	self assert: character greaseInteger = 19982.
	character := Unicode value: 19982.
	self assert: character greaseInteger = 19982.
	LanguageEnvironment allSubclassesDo: [ :each | 
		(each class selectors includes: #leadingChar) ifTrue: [
			"fuck me gently with a chainsaw"
			character := Character 
				leadingChar: each leadingChar
				code: 19982.
			self assert: character greaseInteger = 19982 ] ]! !

!GRPharoPlatformTest methodsFor: 'tests' stamp: 'jf 12/18/2009 12:29'!
testMessageSendValueWithPossibleArguments
	| send |
	send := MessageSend receiver: 1 selector: #+.
	self assert: (send valueWithPossibleArguments: (Array with: 2)) = 3.
	self assert: (send valueWithArguments: (Array with: 2)) = 3.
	self assert: (send value: 2) = 3.

	send := MessageSend receiver: false selector: #not.
	self assert: (send valueWithPossibleArguments: (Array with: 3)).
	
	send := MessageSend receiver: 1 selector: #+ arguments: #(2).
	self assert: (send valueWithPossibleArguments: (Array with: 4)) = 3.
	self assert: send value = 3.
	
	send := MessageSend receiver: Array selector: #with:with: arguments: #(1).
	self assert: (send valueWithPossibleArguments: (Array with: 2)) size = 2.

	send := MessageSend receiver: Array selector: #with:with:.
	self assert: (send value: 1 value: 2) size = 2.
	
	send := MessageSend 
		receiver: 1
		selector: #+.
	self assert: send argumentCount = 1.
	self assert: send arguments size = 0.
	self assert: send fixCallbackTemps == send.
	
	send := MessageSend 
		receiver: 1
		selector: #+
		argument: 2.
	self assert: send argumentCount isZero.
	self assert: send arguments size = 1.
	self assert: send fixCallbackTemps == send! !

!GRPharoPlatformTest methodsFor: 'tests' stamp: 'pmm 8/25/2016 10:59'!
testReadWriteToFileInFolderBinary
	| bytes |
	bytes := #(80 104 39 110 103 108 117 105 32 109 103 108 119 39 110 97 102 104 32 67 116 104 117 108 104 117 32 82 39 108 121 101 104 32 119 103 97 104 39 110 97 103 108 32 102 104 116 97 103 110) asByteArray.
	self 
		writeToFile: bytes 
		withFileNameDo:[ :fileName |
			self assert: (bytes = (GRPlatform current contentsOfFile: fileName binary: true)) ] ! !

!GRPharoPlatformTest methodsFor: 'tests' stamp: 'pmm 8/25/2016 10:59'!
testReadWriteToFileInFolderText
	| text |
	text := 'Ph''nglui mglw''nafh Cthulhu R''lyeh wgah''nagl fhtagn'.
	self 
		writeToFile: text 
		withFileNameDo:[ :fileName |
			self assert: (text = (GRPlatform current contentsOfFile: fileName binary: false)) ] ! !

!GRPharoPlatformTest methodsFor: 'private' stamp: 'JohanBrichau 11/8/2014 10:33'!
writeToFile: aStringOrByteArray withFileNameDo: aBlock
	| fileName directory |
	fileName :=  'GRPharoPlatformTest'.
	directory := FileSystem disk workingDirectory.
	[ GRPlatform current
		write: aStringOrByteArray
		toFile: fileName
		inFolder: directory fullName.
	aBlock value: directory fullName,GRPlatform current pathSeparator,fileName
		] ensure: [
			(directory / fileName) delete ]! !

!GRPlatformTest methodsFor: '*grease-tests-pharo20-core' stamp: 'pmm 9/15/2013 12:27'!
testScaledDecimalGreaseString
	self assert: 123.4s1 greaseString = '123.4'.
	self assert: 123.4s2 greaseString = '123.40'.
	self assert: 123s0 greaseString = '123'! !

!GRPackage class methodsFor: '*grease-tests-pharo20-core' stamp: 'pmm 9/12/2013 16:00'!
greaseTestsPharo20Core
	^ self new
		name: 'Grease-Tests-Pharo20-Core';
		description: 'Unit tests for the package Grease-Pharo-Core.';
		addDependency: 'Grease-Pharo20-Core';
		addDependency: 'Grease-Tests-Core';
		url: #greaseUrl;
		yourself! !
